EcommerceTransactionItem class

Constructors

EcommerceTransactionItem({required String sku, required int price, required int quantity, String? name, String? category})

Properties

category → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
price → int
final
quantity → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited